[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[elpa] externals/auctex 17d1a5d 36/69: ; Merge branch 'simplify-TeX-pars
From: |
Tassilo Horn |
Subject: |
[elpa] externals/auctex 17d1a5d 36/69: ; Merge branch 'simplify-TeX-parse-error' |
Date: |
Sat, 26 Mar 2016 21:36:35 +0000 |
branch: externals/auctex
commit 17d1a5d71f9fb6adbb90e17dbf223f3bf1e2f92a
Merge: f9efa73 1950012
Author: Mosè Giordano <address@hidden>
Commit: Mosè Giordano <address@hidden>
; Merge branch 'simplify-TeX-parse-error'
---
tex-buf.el | 38 +++++++++++++++++++-------------------
1 files changed, 19 insertions(+), 19 deletions(-)
diff --git a/tex-buf.el b/tex-buf.el
index a8ba024..3478590 100644
--- a/tex-buf.el
+++ b/tex-buf.el
@@ -1742,15 +1742,18 @@ command."
(goto-char pt)
(insert-before-markers string)
(set-marker (process-mark process) (point))
;; Remove line breaks at column 79
(while (> (point) pt)
(end-of-line 0)
- (when (and (= (- (point) (line-beginning-position)) 79)
- ;; Heuristic: Don't delete the linebreak if the
- ;; next line is empty or starts with an opening
- ;; parenthesis or if point is located after a period.
+ (when (and (memql (- (point) (line-beginning-position)) '(79 80))
+ ;; Heuristic: Don't delete the linebreak if the next line
+ ;; is empty or starts with an opening parenthesis, or if
+ ;; point is located after a period and in the next line no
+ ;; word char follows.
(not (memq (char-after (1+ (point))) '(?\n ?\()))
- (not (eq (char-before) ?.)))
+ (not (and (eq (char-before) ?.)
+ (char-after (1+ (point)))
+ (not (eq ?w (char-syntax (char-after (1+
(point)))))))))
(delete-char 1)))
(goto-char (marker-position (process-mark process)))
;; Determine current page
@@ -2252,16 +2255,9 @@ Return non-nil if an error or warning is found."
;; TeX error
"^\\(!\\|\\(.*?\\):[0-9]+:\\) \\|"
;; New file
- "(\\(\"[^\"]*?\"\\|/*\
-\\(?:\\.+[^()\r\n{} \\/]*\\|[^()\r\n{} .\\/]+\
-\\(?: [^()\r\n{} .\\/]+\\)*\\(?:\\.[-0-9a-zA-Z_.]*\\)?\\)\
-\\(?:[\\/]+\\(?:\\.+[^()\r\n{} \\/]*\\|[^()\r\n{} .\\/]+\
-\\(?: [^()\r\n{} .\\/]+\\)*\\(?:\\.[-0-9a-zA-Z_.]*\\)?\\)?\\)*\\)\
-)*\\(?: \\|\r?$\\)\\|"
- ;; End of file. The [^:] skips package messages like:
- ;; Package hyperref Message: Driver (autodetected): hpdftex.
- ;; [Loading MPS to PDF converter (version 2006.09.02).]
- "\\()\\)[^:.]\\|"
+ "(\n?\\([^\n())]+\\)\\|"
+ ;; End of file.
+ "\\()\\)\\|"
;; Hook to change line numbers
" !\\(?:offset(\\([---0-9]+\\))\\|"
;; Hook to change file name
@@ -2321,9 +2317,13 @@ Return non-nil if an error or warning is found."
(end (match-end 3)))
;; Strip quotation marks and remove newlines if necessary
(when (or (eq (string-to-char file) ?\")
- (string-match "\n" file))
- (setq file
- (mapconcat 'identity (split-string file "[\"\n]+") "")))
+ (string-match "[ \t\n]" file))
+ (setq file (mapconcat 'identity (split-string file "[\"\n]+")
"")))
+ ;; Trim whitespace at the front/end
+ (setq file
+ (progn
+ (string-match
"^[[:space:]]*\\(.*[^[:space:]]\\)[[:space:]]*$" file)
+ (match-string 1 file)))
(push file TeX-error-file)
(push nil TeX-error-offset)
(goto-char end))
- [elpa] externals/auctex f9efa73 35/69: Another fix for file name regexp in TeX-documentation-texdoc, (continued)
- [elpa] externals/auctex f9efa73 35/69: Another fix for file name regexp in TeX-documentation-texdoc, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 2cca33f 42/69: Minor fix in TeX-documentation-texdoc, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 3dec183 08/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 1950012 31/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 056d8c8 50/69: Fix TeX-check-files, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex f9e6e4b 32/69: New function for reading documentation with texdoc, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex c1dcb84 20/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex fd46872 25/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex c09c405 48/69: Fix wrong usage of `TeX-auto-prepare-hook', Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 6962c34 56/69: Avoid checking duplicate directories in TeX-check-files, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 17d1a5d 36/69: ; Merge branch 'simplify-TeX-parse-error',
Tassilo Horn <=
- [elpa] externals/auctex 416f131 40/69: Catch LaTeX class warnings, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 891bba7 38/69: Add ERT test for error parsing, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex b72dcb7 44/69: Add support for SumatraPDF viewer, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex f1bcbe3 54/69: Improve LaTeX-warnings-regexp, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 08ae29b 19/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 53f2fab 53/69: Another fix for TeX-parse-errro, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex d7f443e 37/69: Add script to update the ChangeLog, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 8b2550e 16/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 2fd59c9 60/69: Improve word-string regexp in TeX-warning, Tassilo Horn, 2016/03/26
- [elpa] externals/auctex 43ba124 23/69: Merge branch 'master' into simplify-TeX-parse-error, Tassilo Horn, 2016/03/26
@@ -1742,15 +1742,18 @@ command."
(insert-before-markers string)
(set-marker (process-mark process) (point))
- ;; Remove line breaks at column 79
+ ;; Remove line breaks at columns 79 and 80
(while (> (point) pt)
(end-of-line 0)